# JuMonC-LogParser

Plugin for JuMonC that allows to parse logs and pass information on to the REST-API of JuMonC from logfiles. By changing the logfile parsing information this plugin can parse different logfiles.